@@ -1,4 +1,4 @@
-from photon_camera import PhotonCamera
+from robotpy_toolkit_7407.sensors.photonvision.photon_camera import PhotonCamera
 from photonvision import PhotonUtils
 from wpimath.geometry import Pose2d, Pose3d, Rotation2d, Translation2d
 from robotpy_apriltag import AprilTagFieldLayout
